Obtain Monte Carlo draws from posterior distribution of stagewise regression parameters
compute_MC_draws_mvt(
Data,
tau,
num_treats,
B,
nu0 = 3,
V0 = mapply(diag, p_list, SIMPLIFY = FALSE),
alph,
gam,
p_list,
showBar = TRUE
)Monte Carlo draws??? A list containing:
sigmat_B_list: Desc. A list of length num_stages with each element a vector of size B x p_t
Wt_B_list: Desc. A list of length num_stages with each element a matrix of size B x p_t
beta_B: Desc. A list of length B
sigmay_2B: Desc. A list of length B
Observed data organised as a list of \(\{y, X, A\}\) where y is a vector of the final outcomes, X is a list of matrices of the intermediate covariates and A is a matrix of the assigned treatments
Prior precision scale. Should be specified with a small value
Vector of number of treatment options at each stage
Number of MC draws
Inverse-Wishart degres of freedom. default: 3
Inverse-Wishart scale matrix. default: diagonalisation of p_list
Inverse-Gamma prior shape parameter for regression error variance of y. default: 1
Inverse-Gamma prior rate parameter for regression error variance of y. default: 1
Vector of dimension for each stage
Whether to show a progress bar. Uses bar from progress_bar deafult: TRUE