Generate Univariate Dataset
generate_dataset_uvt(n, num_stages, num_treats)Observed data organised as a list of \(\{y, X, A\}\) where y is a vector of the final outcomes, X is a list of matrices of the intermediate covariates and A is a matrix of the assigned treatments
Number of samples/individuals to generate
Total number of stages per individual
Vector of number of treatment options at each stage