Methods to estimate optimal dynamic treatment regimes using Bayesian likelihood-based regression approach as described in Yu, W., & Bondell, H. D. (2023) tools:::Rd_expr_doi("10.1093/jrsssb/qkad016") Uses backward induction and dynamic programming theory for computing expected values. Offers options for future parallel computing.
Maintainer: Jeremy Lim jeremylim23@gmail.com
Authors:
Weichang Yu weichang.yu@unimelb.edu.au (ORCID)
Yu, W., & Bondell, H. D. (2023), “Bayesian Likelihood-Based Regression for Estimation of Optimal Dynamic Treatment Regimes”, Journal of the Royal Statistical Society Series B: Statistical Methodology, 85(3), 551-574. tools:::Rd_expr_doi("doi:10.1093/jrsssb/qkad016")
generate_dataset() for generating a toy dataset to test the model fitting on
BayesLinRegDTR.model.fit() for obtaining an estimated posterior
distribution of the optimal treatment option at a user-specified prediction stage
Useful links: